@@ -9,7 +9,7 @@ use Carp qw( carp croak );
 use Path::Tiny;
 
 use vars qw( $VERSION );
-$VERSION = '2.09'; 
+$VERSION = '2.10'; 
 
 use Object::Tiny::RW 
 	'comment',			# True to create the %%[] comment macro
@@ -423,12 +423,9 @@ sub expand_file { # Object method.
 
 	croak "Missing filename"            unless     $file; 
 	
-	substr( $file, 0, 1 ) = ( $ENV{HOME} or $ENV{LOGDIR} or (getpwuid( $> ))[7] ) 
-	if substr( $file, 0, 1 ) eq '~';
+	# let Path::Tiny handle '~' processing
+	$file = path($file);
 	
-	croak "File '$file' does not exist" unless  -e $file;
-    
-
 	local $_;
 
 	open my $fh, $file or croak "Open '$file' failed: $!";
